package application;

import java.io.UnsupportedEncodingException;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.security.SecureRandom;

import javafx.collections.FXCollections;
import javafx.collections.ObservableList;
import javafx.event.ActionEvent;
import javafx.fxml.FXML;
import javafx.scene.control.ChoiceBox;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextField; 

public class MainController {
	
	ObservableList<String> hashFunctionList = 
			FXCollections.observableArrayList("MD5", "SHA-1", "SHA-224", "SHA-256", "SHA-384", "SHA-512");
	
	@FXML
	private TextArea inputText;
	
	@FXML
	private TextField hashValue;
	
	@FXML
	private ChoiceBox<String> hashFunctionBox;
	
	@FXML
	private void initialize() {
		hashFunctionBox.setValue("SHA-1");
		hashFunctionBox.setItems(hashFunctionList);
	}
	
	public void genRandomInput(ActionEvent event) throws NoSuchAlgorithmException, UnsupportedEncodingException {
		SecureRandom sr = SecureRandom.getInstance("SHA1PRNG");
		byte[] randBytes = new byte[32];
		sr.nextBytes(randBytes); 
		inputText.setText(bytes2Hex(randBytes));
	}
	
	public void computeHash(ActionEvent event) throws NoSuchAlgorithmException, UnsupportedEncodingException {
		String hash = hashFunctionBox.getValue();
		MessageDigest md = MessageDigest.getInstance(hash);
		md.update(((String) inputText.getText()).getBytes());
		byte[] digest = md.digest();
		hashValue.setText(bytes2Hex(digest));		
	}
	
	public static String bytes2Hex(byte[] bytes) {
		StringBuilder sb = new StringBuilder();
        for (int i = 0; i < bytes.length; i++) {
            sb.append(Integer.toString((bytes[i] & 0xff) + 0x100, 16).substring(1));
        }
        return sb.toString();
	}
	

}
